function Salmon_risk
% Atlantic salmon risk analysis calculator
% Marc Mangel and Andi Stephens, 2003.

clear all; clc;

% Global variables for plotting results
global Grilse Adults Invaders Grilse2 Adults2 Invaders2 Description Run

% Global variables for user-defined simulations
global NA NI EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE ESC A_e S_e PULSE DISEASE

% Global variables for reproduction of escaped smolts

global pct_repro repr_lag 

% Global variables
global maxdate mindate aqua_date

mindate = 1500;
maxdate = 2105;
maxsmolts = 20;
aqua_date = 2003; % Date aqauculured fish start escaping

plot_choice = 0;  % Don't yet know what user wants
Quit = 0;
Run = 1;          % For numbering windows
   

% Use Escape function to calculate reproduction, survival and reproductive lag
% for smolts escaping on a range of dates each year.

h = waitbar(0,'Please wait, initializing...');

escape_date = 90;
for i = 1:maxsmolts
    [repro_dist(i,:), surv_dist(i,:), repr_lag(i)] = Escape(escape_date);
    escape_date = escape_date + round((365-90)/maxsmolts);
    waitbar(i/maxsmolts)
end
close(h);

while Quit == 0
    
    initialize_globals;
    
    % Translate survival-to-reproduction from a distribution
    % to a percentage for each escaping smolt, each year.
    
    for i = 1:maxsmolts
        pct_repro(i,:) = dist_to_percent(repro_dist(i,:), maxdate-aqua_date);
    end
           
    % Prompt user for simulation conditions
    [NA, NI, EGG, PARR, PRED, GEN, ESC, PULSE, DISEASE, Quit] = conditions;
    
    % Exit if requested
    if Quit == 1
        break;
    end
    % Calculate trajectories for conditions requested
    [Grilse,Adults,Invaders] = calculate_fish(pct_repro,repr_lag,maxsmolts);
    
    % Recalculate under managed conditions unless no aquaculture
    if ~NA
        % Get user values for management actions
        [RED_RATE, RECAP_RATE] = management;
        if RED_RATE ~= 17
            E_RED = 1;
        end
        if RECAP_RATE ~= 17
            RECAP = 1;
        end
        
        % Calculate trajectories again with management actions
        if (E_RED || RECAP)
            [Grilse2,Adults2,Invaders2] = calculate_fish(pct_repro,repr_lag,maxsmolts);
        else
            Grilse2 = Grilse;
            Adults2 = Adults;
            Invaders2 = Invaders;
        end
    end
       
   
    % Plot results, get user preference the first time
    
    if Run == 1
        plot_choice = results;
    end
    
    % Create description of simulation and management actions and results
    
    if ispc
        Create_text_PC;
        Plotup_PC(plot_choice);
    else
        Create_text_MAC;
        Plotup_MAC(plot_choice);
    end
end % main while loop

%********************** Fish Calculation **************************

function [A_11, A_22, A_aqua] = calculate_fish(pct_repro,repr_lag,maxsmolts)

% Calculate population trajectories.  Uses global variables describing
% Simulation conditions, dates

global NA NI EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE ESC A_e S_e PULSE
global maxdate mindate aqua_date DISEASE 

% Parameters from guesses
wild_kill = .95;
pred_enhancement = .8;
pred_enhancement_aqua = .6;
rho_a = .3;      % probability of assortative mating


S_e = maxsmolts;
A_e = 100;

switch ESC
    case 2
        A_e = 0;
    case 3
        S_e = 0;
end

if NA
    S_e = 0;
    A_e = 0;
end

Ae_orig = A_e;
Se_orig = S_e;

adult_capture = 1;
escape_reduction = 1;

if RECAP
    adult_capture = RECAP_RATE;
    wild_kill = wild_kill + (1-wild_kill)*RECAP_RATE;
end
if E_RED
    escape_reduction = RED_RATE;
end

% Parameters From The Atlantic Salmon Stocks Report
% http://library.fws.gov/salmon/asalmon3.html

% Sigmas are survival rates

sig_0 = .08;      % sig_0 Section 3, para 7 (avg survival to fry * avg survival to parr)
sig_1 = .5;       % sig_1 Section 3, para 9  Survival to 1st-year smolt
sig_2 = .6;       % sig_2 Section 3, para 9  Survival a second year in-stream
sig_3 = (.1)^(1/2); % sig_3	Section 7.5.2  Ocean year survival rate

f = .8;           % f	Section 3, para 11  Percent of parr that smolt after 2 years
g_1 = 0.05;       % g_1	Section 3, para 3 & 4  One-year smolts that return as grilse
g_2 = 0.05;       % g_2	Section 3, para 3 & 4  Two-year smolts that return as grilse
e_1 = 5400;       % e_1	Section 3, para 6  Egg production of a 1-SW female
e_2 = 7200;       % e_2	Section 3, para 6  Egg production of a 2-SW female

rho_maladapt = .3;   % per Fleming et al Proc Roy Soc  paper

% cross_surv = 0; % survival to hatch of crosses (pg 11 NOAA tech on Atlantics in Puget Sound)

cross_surv = .5;  % GUESS.  Can't be zero, as above, because they're all Atlantics.

% Betas are density dependence

beta_e = .00001/2;
beta_11 = .0001;
beta_21 = 0.0001;
beta_22 = 0.0001;


% Initialize populations

R_11 = zeros(1,maxdate);
R_21 = zeros(1,maxdate);
R_22 = zeros(1,maxdate);
E = zeros(1,maxdate);
S_1 = zeros(1,maxdate);
S_2 = zeros(1,maxdate);
A_11 = zeros(1,maxdate);
A_21 = zeros(1,maxdate);
A_22 = zeros(1,maxdate);
E_aqua = zeros(1,maxdate);
R_aqua = zeros(1,maxdate);
S_aqua = zeros(1,maxdate);
S_hybrid = zeros(1,maxdate);
A_aqua = zeros(1,maxdate);


% Starting Population

A_11(mindate+1) = 30;
A_22(mindate+1) = 220;

Fcap = setup_fishing;
[h_f,h_o] = setup_habitat;

% Pre-aquaculture

for t = mindate+1:(aqua_date-1)
    
    E(t+1) = e_1*h_f(t)*A_11(t)*exp(-Fcap(t)) + e_2*h_f(t)*A_22(t)*exp(-Fcap(t));
    
    egg_comp = 1/(1 + beta_e*E(t));
    
    R_11(t+1) = sig_0*E(t)*egg_comp*h_f(t)*f;
    R_21(t+1) = sig_0*E(t)*egg_comp*h_f(t)*(1-f);
    R_22(t+1) = sig_2*R_21(t)*h_f(t);
    
    comp_term = 1/(1 + beta_11*R_11(t) + beta_21*R_21(t) + beta_22*R_22(t) );
    
    S_1(t+1) = h_f(t)*sig_1*R_11(t)*comp_term;
    S_2(t+1) = h_f(t)*sig_1*f*R_22(t)*comp_term;
    
    A_11(t+1) = sig_3*h_o(t)*(g_1*S_1(t) + g_2*S_2(t));
    A_21(t+1) = sig_3*h_o(t)*((1-g_1)*S_1(t-1) + (1-g_2)*S_2(t));
    A_22(t+1) = sig_3*A_21(t);
end % Pre-aquaculture

% Aquaculture begins

for t = aqua_date:maxdate-1
    
    A_e = Ae_orig;
    S_e = Se_orig;
    
    if PULSE && (t == 2030 || t == 2060 || t == 2061 || t == 2062 || (t > 2079 && t < 2086))
        A_e = 5000;
        S_e = 1000;
    end
    
    % Add in lagged reproducing smolts
    
    for i = 1:maxsmolts
        if t+1 > repr_lag(i) + aqua_date;
            A_aqua(t) = A_aqua(t) + (1/maxsmolts) * S_aqua(t-repr_lag(i))*pct_repro(i,t-aqua_date);
        end
    end
    
    E(t+1) = e_1*h_f(t)*A_11(t)*exp(-Fcap(t)) + e_2*h_f(t)*A_22(t)*exp(-Fcap(t));
    E_aqua(t+1) = rho_maladapt*e_1*A_aqua(t);
    
    % Genetic introgression
    
    if GEN
        q = (E(t+1)/(E(t+1) + E_aqua(t+1)))^2;  
        E_prime = E(t+1) * ( rho_a + q*(1-rho_a) );
        E_aqua(t+1) = E_aqua(t+1) + cross_surv*(E(t+1)-E_prime);
        E(t+1) = E_prime;
    end
    
    % Egg competition for natural fish
    
    switch EGG
        case 1
            egg_comp = 1/(1 + beta_e*(E(t)));
        case 2
            eta = 1;
            egg_comp = 1/(1 + beta_e*((E(t) + eta * E_aqua(t))));
        case 3
            eta = 1.25;
            egg_comp = 1/(1 + beta_e*((E(t) + eta * E_aqua(t))));
        case 4
            eta = 1.5;
            egg_comp = 1/(1 + (beta_e*(E(t) + eta * E_aqua(t))));
     end
    
    % Parr
    
    R_11(t+1) = sig_0*E(t)*egg_comp*h_f(t)*f;
    R_21(t+1) = sig_0*E(t)*egg_comp*h_f(t)*(1-f);
    R_22(t+1) = sig_2*R_21(t)*h_f(t);
    
    % Egg competition for farmed fish
    
	if EGG == 1
        if NA || NI
            egg_comp = 1/(1 + beta_e*E_aqua(t));
        end
	end
        
    % Farmed Parr
    
    R_aqua(t+1) = sig_0*rho_maladapt*E_aqua(t)*egg_comp*h_f(t);
    
    % Parr competition for natural fish
        
    switch PARR
        case 1
            comp_term = 1/(1 + beta_11*R_11(t) + beta_21*R_21(t) + beta_22*R_22(t) );
        case 2
            gamma = 1;
            comp_term = 1/(1 + (beta_11*( R_11(t) + gamma * R_aqua(t) ) + beta_21*R_21(t) + beta_22*R_22(t) ));
        case 3
            gamma = 2;
            comp_term = 1/(1 + (beta_11*( R_11(t) + gamma * R_aqua(t) ) + beta_21*R_21(t) + beta_22*R_22(t) ));
        case 4
            gamma = 3;
            comp_term = 1/(1 + (beta_11*( R_11(t) + gamma * R_aqua(t) ) + beta_21*R_21(t) + beta_22*R_22(t) ));
    end
    
    % Smolts

    
    S_1(t+1) = h_f(t)*sig_1*R_11(t)*comp_term;
    S_2(t+1) = h_f(t)*sig_1*f*R_22(t)*comp_term;
    
    % Parr competition for farmed fish
    
    if NA || NI
        comp_term = 1/(1 + beta_11*R_aqua(t));
    end
   
    % Farmed smolts
    
    S_hybrid(t+1) = h_f(t)*sig_1*rho_maladapt*R_aqua(t)*comp_term;
    S_aqua(t+1) = S_e*escape_reduction; 
    
    % Natural adults
    
    if DISEASE
        N = S_1(t) + S_2(t) + S_hybrid(t) + S_aqua(t);
        ds = disease_calc(N);  % Disease survivorship
    else
        ds = 1;
    end
    A_11(t+1) = ds*sig_3*h_o(t)*(g_1*S_1(t) + g_2*S_2(t));
    A_21(t+1) = ds*sig_3*h_o(t)*((1-g_1)*S_1(t-1) + (1-g_2)*S_2(t));
    
    % Note: A_22s are out at sea, don't get diseased.
    
    A_22(t+1) = sig_3*h_o(t)*A_21(t);
    
    % Enhanced predation pressure on smolts reduces adult returns
    
    if PRED
        A_11(t+1) = pred_enhancement*A_11(t+1);
        A_22(t+1) = pred_enhancement*A_22(t+1);
    end
    
    if RECAP
        A_11(t+1) = A_11(t+1)*wild_kill;
        A_22(t+1) = A_22(t+1)*wild_kill;
    end 

    % Farmed adults       
    
    A_aqua(t+1) = adult_capture*(A_e*escape_reduction + rho_maladapt*sig_3*ds*S_hybrid(t));
    
    % Enhanced predation pressure on smolts reduces farmed adults
    
    if PRED
        A_aqua(t+1) = pred_enhancement_aqua*A_aqua(t+1);
    end
    
    
end % Aquaculture period

% figure;
% semilogy(S_hybrid(1990:2100));hold on;
% semilogy(S_aqua(1990:2100),'r');
% semilogy(A_aqua(1990:2100), 'g');
% semilogy(E_aqua(1990:2100), 'c');
% semilogy(R_aqua(1990:2100), '.');

% end function calculate_fish


%********************** Initialize globals **************************

% These are reused each time through the main loop.  Must be reset.

function initialize_globals;

global Grilse Adults Invaders Grilse2 Adults2 Invaders2
global NA NI EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE PULSE
global Description maxdate aqua_date repr_lag

Grilse = zeros(1,maxdate);
Adults = zeros(1,maxdate);
Invaders = zeros(1,maxdate);
Grilse2 = zeros(1,maxdate);
Adults2 = zeros(1,maxdate);
Invaders2 = zeros(1,maxdate);

NA = 0;
NI = 0;
EGG = 0;
PARR = 0;
PRED = 0;
GEN = 0;
E_RED = 0;
RED_RATE = 0;
RECAP = 0;
RECAP_RATE = 0;
PULSE = 0;
Description = '';

% end function initialize_globals
    

%********************** Fishing setup **************************

function Fcap = setup_fishing;

global maxdate mindate

Fcap = zeros(1,maxdate);
for t = mindate:1770
    Fcap(t) = 0;
end
for t = 1771:1985
    Fcap(t) = 1;
end
for t = 1986:maxdate
    Fcap(t) = 0;
end

% end function setup_fishing.


%********************** Habitat setup **************************

function [h_f,h_o] = setup_habitat;

% Habitat loss
% freshwater habitat drops by 50% in 150 years

global maxdate mindate

h_f = ones(1,maxdate);    % Freshwater habitat
h_o = ones(1,maxdate);    % Seawater habitat (unchanging)

deg_coeff = -log(.5)/150;

for t = mindate:1835
    h_f(t) = 1;
end
for t = 1836:maxdate
    h_f(t) = exp(-deg_coeff*(t - 1835));	
    if h_f(t) < 0.5
        h_f(t) = 0.5;
    end
end

% Option in which habitat is improved

improv = 0;
for t = 2000:maxdate
    h_f(t) = h_f(t-1)*(1 + improv);
    if h_f(t) > 1
        h_f(t) = 1;
    end
end
% end function setup_habitat

%********************** Disease *****************************

% Placeholder for more interesting disease function

function fcn_not_diseased = disease_calc(N)

fcn_not_diseased = .9;

% end function disease


%********************** Aqua Reproduction *******************

function pct_repro = dist_to_percent(repro_dist, numyears)

distribution = sort(nonzeros(repro_dist));

a = 1; b = length(distribution);
c = a + (b-a) * rand(1,numyears);
c = round(c);

pct_repro = zeros(1,length(c));
for i = 1:length(c)
    pct_repro(i) = 100 * distribution(c(i));
end


% end function dist_to_percent

%********************** Text setup **************************

function Create_text_MAC

global Grilse Adults Invaders Grilse2 Adults2 Invaders2
global NA NI EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE A_e S_e
global Description maxdate mindate aqua_date PULSE DISEASE

Description = sprintf('\n\n%s\n', 'Simulation conditions:');

output(1) = Grilse(maxdate-5) + Adults(maxdate-5);
if output(1) < 1
    output(1) = 0;
end
output(2) = Invaders(maxdate-5);

strvals = strvcat('no', 'low', 'medium', 'high');
esc_descr = sprintf('%s\t%d%s%d', 'Escape rate (smolts:adults)', S_e, ':', A_e);

if NA
    output(2) = 0;
    Description = sprintf('%s\n\t%s', Description, 'No Aquaculture');
else
    Description = sprintf('%s\n\t%s', Description, esc_descr);
    if NI
        Description = sprintf('%s\n\t%s', Description, 'No Interaction');
    end
    if EGG ~= 1
        Description = sprintf('%s\n\t%s%s', Description, 'Egg competition ', strvals(EGG,:));
    end
    if PARR ~= 1
        Description = sprintf('%s\n\t%s%s', Description, 'Parr competition ', strvals(PARR,:));
    end
    if PRED
        Description = sprintf('%s\n\t%s', Description, 'Enhanced predation');
    end
    if GEN
        Description = sprintf('%s\n\t%s', Description, 'Genetic introgression');
    end
    if DISEASE
        Description = sprintf('%s\n\t%s', Description, 'Disease');
    end
    if PULSE
        Description = sprintf('%s\n\t%s%s', Description, '        ', 'With additional catastrophic escapes');
    end
    
    % If management actions occurred
    if (E_RED | RECAP)
        Description = sprintf('%s\n\n%s\n', Description, 'Managment actions:');
        if E_RED
            Description = sprintf('%s\n\t%s\t\t%d%s', Description, 'Escape reduction', 100 - RED_RATE * 100,' %');
        end
        if RECAP
            Description = sprintf('%s\n\t%s\t%d%s', Description, 'Recapture of escaped fish', 100 - RECAP_RATE * 100, ' %');
        end
        output(4) = Invaders2(maxdate-5);
        output(3) = Grilse2(maxdate-5) + Adults2(maxdate-5);
        if output(3) < 1
            output(3) = 0;
        end
    end % if management actions 
    
end % if NA

Description = sprintf('%s\n\n%s\n', Description, 'Fish stocks in year 2100 (no management):');
Description = sprintf('%s\n\t%s\t\t%s', Description, 'Wild', 'Farmed');
Description = sprintf('%s\n\n\t%g%s\t\t%g',  Description, output(1), '  ',output(2));

if (E_RED | RECAP)
	Description = sprintf('%s\n\n%s\n', Description, 'Fish stocks in year 2100 (with management):');
	Description = sprintf('%s\n\t%s\t\t%s', Description, 'Wild', 'Farmed');
	Description = sprintf('%s\n\n\t%g%s\t\t%g',  Description, output(3), '  ',output(4));
end

% end function setup_text_Mac

%********************** Setup_text_PC *************************

function Create_text_PC

global Grilse Adults Invaders Grilse2 Adults2 Invaders2
global NA NI EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE
global Description maxdate mindate aqua_date PULSE DISEASE

Description = sprintf('\n\n%s\n', 'Simulation conditions:');

output(1) = Grilse(maxdate-5) + Adults(maxdate-5);

if output(1) < 1
    output(1) = 0;
end

strvals = strvcat('no', 'low', 'medium', 'high');


if NA
    output(2) = 0;
    Description = sprintf('%s\n%s', Description, '     No Aquaculture');
else
    output(2) = Invaders(maxdate-5);
    if NI
        Description = sprintf('%s\n%s', Description, '     No Interaction');
    end
    if EGG ~= 1
        Description = sprintf('%s\n%s%s', Description, '     Egg competition ', strvals(EGG,:));
    end
    if PARR ~= 1
        Description = sprintf('%s\n%s%s', Description, '     Parr competition ', strvals(PARR,:));
    end
    if PRED
        Description = sprintf('%s\n%s', Description, '     Enhanced predation');
    end
    if GEN
        Description = sprintf('%s\n%s', Description, '     Genetic introgression');
    end
    if DISEASE
        Description = sprintf('%s\n\t%s', Description, 'Disease');
    end
    if PULSE
        Description = sprintf('%s\n\t%s%s', Description, '      ', 'With additional catastrophic escapes');
    end

    
    % If management actions occurred
    if (E_RED | RECAP)
        Description = sprintf('%s\n\n%s\n', Description, 'Managment actions:');
        if E_RED
            Description = sprintf('%s\n%s%d%s', Description, '     Escape reduction                 ', 100 - RED_RATE * 100,' %');
        end
        if RECAP
            Description = sprintf('%s\n%s%d%s', Description, '     Recapture of escaped fish  ', 100 - RECAP_RATE * 100, ' %');
        end
        output(4) = Invaders2(maxdate-5);
        output(3) = Grilse2(maxdate-5) + Adults2(maxdate-5);
        if output(3) < 1
            output(3) = 0;
        end
    end % if management actions 
    
end % if NA

Description = sprintf('%s\n\n%s\n', Description, 'Fish stocks in year 2100 (no management):');
Description = sprintf('%s\n%s%s', Description, '     Wild', '                Farmed');
Description = sprintf('%s\n\n%s%g%s%g',   Description, '     ', output(1), '            ',output(2));

if (E_RED | RECAP)
	Description = sprintf('%s\n\n%s\n', Description, 'Fish stocks in year 2100 (with management):');
	Description = sprintf('%s\n%s%s', Description, '     Wild', '                Farmed');
	Description = sprintf('%s\n\n%s%g%s%g',  Description, '     ', output(3), '            ',output(4));
end


% end function setup_text_PC

%********************** Plot Results **************************

function Plotup_MAC(plot_choice)

global Grilse Adults Invaders Grilse2 Adults2 Invaders2
global NA EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE
global Description maxdate mindate aqua_date Run PULSE


set(0, 'DefaultLineLineWidth', 2);
set(0, 'DefaultTextFontName', 'Helvetica');
set(0, 'DefaultTextFontWeight', 'normal');
set(0, 'DefaultTextFontSize', 12);
set(0, 'DefaultAxesFontName', 'Helvetica');
set(0, 'DefaultAxesFontWeight', 'bold');
set(0, 'DefaultAxesFontSize', 12);
set(0, 'DefaultAxesLineWidth', 2);

windowname_1 = sprintf('%s%g', 'Trajectories for Simulation ', Run);
windowname_2 = sprintf('%s%g', 'Results for Simulation ', Run);
Run = Run + 1;

if plot_choice == 1          % write to command window
    disp(Description);
    
else
    scrsz = get(0,'ScreenSize');
    figure('Position', [scrsz(3)/2 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2], ...
        'NumberTitle', 'off', 'Name', windowname_1, 'MenuBar', 'none');
    set(gcf,'Color',[1,1,1])
    
    if NA
        plot(Grilse); hold on;
        plot(Adults, 'r');
        p = patch([1771 1771 1985 1985], [0 300 300 0],'r'); hold on;
        set(p, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        text(1650, 200, 'Pre-fishing');
        text(1780, 200, 'Overfishing and habitat destruction');
        g = patch([2003 2003 2100 2100], [0 300 300 0], 'b');
        set(g, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        myline = sprintf('%s\n%s\n%s', 'Habitat', 'improvement', 'No fishing');
        text(2010, 190, myline);
        m = patch([1600 1600 1770 1770], [0 300 300 0], 'y');
        set(m, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        legend('Wild Grilse', 'Wild 2-year Salmon');
        plot([1601 1601], [0 300], 'k');
        axis([1600 2100 0 300]);
    else
        plot (Grilse2, 'b'); hold on;
        plot (Adults2, 'r');         
        plot(Invaders2, 'k');
        xlabel 'Year';
        ylabel 'Population';
        if PULSE
            axis([1990 2100 0 500]);
        else
            axis([1990 2100 0 150]);
        end
             
        if plot_choice == 2 ||  (~RECAP & ~E_RED)       % Only plotting post-managment populations
            legend('Wild Grilse', 'Wild 2-year Salmon', 'Aquaculture Salmon');
        else                                            % Plot before management populations
            plot(Grilse, 'b--');
            plot(Adults, 'r--');
            plot(Invaders, 'k--');
            legend('Wild Grilse', 'Wild 2-year Salmon', 'Aquaculture Salmon', ...
                'Wild Grilse, no management', 'Wild 2-year Salmon, no management', ...
                'Aquaculture Salmon, no management');
        end
    end
    figure('Position',[1 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2], ...
        'Color', 'white', 'MenuBar', 'none', 'Name', windowname_2, ...
        'NumberTitle', 'off');
    axes('Visible', 'off'); %, 'Position', [0.1 0.1 0.95 0.95]);
    axis([0 100 0 100]);
    text(0, 65, Description);
    
end % If plotting

% end function plotup_MAC

%********************** Plot Results **************************

function Plotup_PC(plot_choice)

global Grilse Adults Invaders Grilse2 Adults2 Invaders2
global NA EGG PARR PRED GEN E_RED RED_RATE RECAP RECAP_RATE
global Description maxdate mindate aqua_date Run PULSE


set(0, 'DefaultLineLineWidth', 1.5);
% set(0, 'DefaultTextFontName', 'Helvetica');
% set(0, 'DefaultTextFontWeight', 'normal');
% set(0, 'DefaultTextFontSize', 12);
% set(0, 'DefaultAxesFontName', 'Helvetica');
% set(0, 'DefaultAxesFontWeight', 'bold');
% set(0, 'DefaultAxesFontSize', 12);
set(0, 'DefaultAxesLineWidth', 1.5);

windowname_1 = sprintf('%s%g', 'Trajectories for Simulation ', Run);
windowname_2 = sprintf('%s%g', 'Results for Simulation ', Run);
Run = Run + 1;

if plot_choice == 1          % write to command window
    disp(Description);
    
else
    scrsz = get(0,'ScreenSize');
    figure('Position', [scrsz(3)/2 (scrsz(4)/2 - 10) scrsz(3)/2  (scrsz(4)/2 - 10)], ...
        'NumberTitle', 'off', 'Name', windowname_1, 'MenuBar', 'none');
    set(gcf,'Color',[1,1,1])
    
    if NA
        plot(Grilse); hold on;
        plot(Adults, 'r');
%         p = patch([1771 1771 1985 1985], [0 300 300 0],'r'); hold on;
%         set(p, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        text(1650, 200, 'Pre-fishing');
        myline = sprintf('%s\n%s', 'Overfishing and', 'habitat destruction');
        text(1780, 200, myline);
%         g = patch([2003 2003 maxdate maxdate], [0 300 300 0], 'b');
%         set(g, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        myline = sprintf('%s\n%s\n%s', 'Habitat', 'improvement', 'No fishing');
        text(2010, 190, myline);
%         m = patch([1600 1600 1770 1770], [0 300 300 0], 'y');
%         set(m, 'edgecolor', 'none', 'FaceAlpha', 0.2);
        legend('Wild Grilse', 'Wild 2-year Salmon');
        plot([1601 1601], [0 300], 'k');
        axis([1600 2100 0 300]);
    else
        plot (Grilse2, 'b'); hold on;
        plot (Adults2, 'r');         
        plot(Invaders2, 'k');
        xlabel 'Year';
        ylabel 'Population';
        if PULSE
            axis([1990 2100 0 500]);
        else
            axis([1990 2100 0 150]);
        end
             
        if plot_choice == 2 ||  (~RECAP & ~E_RED)       % Only plotting post-managment populations
            legend('Wild Grilse', 'Wild 2-year Salmon', 'Aquaculture Salmon');
        else                                            % Plot before management populations
            plot(Grilse, 'b--');
            plot(Adults, 'r--');
            plot(Invaders, 'k--');
            legend('Wild Grilse', 'Wild 2-year Salmon', 'Aquaculture Salmon', ...
                'Wild Grilse, no management', 'Wild 2-year Salmon, no management', ...
                'Aquaculture Salmon, no management');
        end
    end
    figure('Position',[1 (scrsz(4)/2 - 10) scrsz(3)/2 (scrsz(4)/2 - 10)], ...
        'Color', 'white', 'MenuBar', 'none', 'Name', windowname_2, ...
        'NumberTitle', 'off');
    axes('Visible', 'off'); %, 'Position', [0.1 0.1 0.95 0.95]);
    axis([0 100 0 100]);
    text(0, 55, Description);
    
end % If plotting

% end function plotup_PC

% That's all, folks!
